# Database

It can be imported from `fluid.db`:

It requires the `db` extra to be installed:

```bash
pip install aio-fluid[db]
```

```python
from fluid.db import Database
```

::: fluid.db.Database
